package App::cpx;

use 5.006;
use strict;
use warnings;

=head1 NAME

App::cpx - Install and execute CPAN package binaries

=head1 VERSION

Version 0.04

=cut

our $VERSION = '0.04';


=head1 SYNOPSIS

Perhaps a little code snippet.

    cpx mlocate Redis Moo

=head1 AUTHOR

Thibault DUPONCHELLE, C<< <thibault.duponchelle at gmail.com> >>

=head1 LICENSE AND COPYRIGHT

This software is Copyright (c) 2024 by Thibault DUPONCHELLE.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)


=cut

1; # End of App::cpx
